# -*- coding: utf-8 -*-

"""Package for abstract_scorm_xblock."""

__author__ = "Alexander Marenich, Andrey Kryachko, Andrey Lykhoman, COTOHA, David Baumgold, Volodymyr Bergman, Maxim Starodubcev, Jorge Mora, Silvio Tomatis, kirkerafael, Oksana Slusarenro, Chiruzzi Marco"
__maintainer__ = "Silvio Tomatis, Chiruzzi Marco"
__email__ = "silviot@gmail.com, chiruzzi.marco@gmail.com"
__version__ = "1.0.0"
