/* CSS for ScormXBlock */
.scormxblock_block .scorm_object {
  border: none;
}

span.setting-input-file {
  padding-left: 25%;
  margin-left: 14px;
  padding-top: 5px;
}

span.setting-input-file span {
  font-weight: bold;
}
